@@ -17,7 +17,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Minolta;
 
-$VERSION = '1.16';
+$VERSION = '1.17';
 
 sub ProcessMRW($$;$);
 sub WriteMRW($$;$);
@@ -489,6 +489,14 @@ sub ProcessMRW($$;$)
         $err and $et->Error("MRW format error", $$et{TIFF_TYPE} eq 'ARW');
     } else {
         $err and $et->Warn("MRW format error");
+        if ($$et{ImageDataMD5}) {
+            my ($num, $md5) = (0, $$et{ImageDataMD5});
+            while ($raf->Read($data, 65536)) {
+                $md5->add($data);
+                $num += length $data;
+            }
+            $et->VPrint(0, "$$et{INDENT}(ImageDataMD5: $num bytes of raw data)\n");
+        }
     }
     return $rtnVal;
 }
@@ -512,7 +520,7 @@ write Konica-Minolta RAW (MRW) images.
 
 =head1 AUTHOR
 
-Copyright 2003-2022, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2023, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
